BuildRequires: chrpath
BuildRequires: libhdf5-devel SuperLU-devel
# BEGIN SourceDeps(oneline):
BuildRequires(pre): rpm-macros-fedora-compat
BuildRequires: /usr/bin/gcov /usr/bin/git /usr/bin/lcov gcc-c++ libatlas-devel liblapack-devel openmpi-devel
# END SourceDeps(oneline)
# see https://bugzilla.altlinux.org/show_bug.cgi?id=10382
%define _localstatedir %{_var}
Name:           mlpack
Version:        2.2.5
Release:        alt3_1
Summary:        Scalable, fast C++ machine learning library

Group:          System/Libraries
License:        LGPLv3+
URL:            http://www.mlpack.org
Source0:        http://www.mlpack.org/files/%{name}-%{version}.tar.gz

# CMake by default doesn't provide support for specifying libdir on install
# (argh!) and this has to be done by hand in the CMake configuration.
Patch0:         cmake_libdir.patch

# By default the mlpack Doxyfile excludes all files in the directory pattern
# */build/*.  Well, on Koji, that's everything.  So we need to not exclude
# that.
Patch1:		no_exclude_build.patch

# Newer versions of Doxygen choke on the TreeTraits definitions for some reason.
Patch2:		doxygen.patch


BuildRequires:  ctest cmake

BuildRequires:  armadillo-devel >= 4.200.0
BuildRequires:  boost-asio-devel boost-context-devel boost-coroutine-devel boost-devel boost-devel-headers boost-filesystem-devel boost-flyweight-devel boost-geometry-devel boost-graph-parallel-devel boost-interprocess-devel boost-locale-devel boost-lockfree-devel boost-log-devel boost-math-devel boost-mpi-devel boost-msm-devel boost-multiprecision-devel boost-polygon-devel boost-program_options-devel boost-python-devel boost-python-headers boost-signals-devel boost-wave-devel, boost-program-options, boost-math, boost-serialization >= 1.49
BuildRequires:  pkg-config

# For generating man pages (CMake configuration takes care of this assuming
# txt2man is installed).  It is possible that we could just add all the man
# pages, generated offline, as a patch to this SRPM, but txt2man seems to exist
# in repos.
BuildRequires:  txt2man
# For generation of Doxygen HTML documentation.
BuildRequires:  doxygen
BuildRequires:  graphviz libgraphviz

# something doesn't like size_t being unsigned long on s390
ExcludeArch:    s390
Source44: import.info

%description
mlpack is a C++ machine learning library with emphasis on scalability, speed,
and ease-of-use. Its aim is to make machine learning possible for novice users
by means of a simple, consistent API, while simultaneously exploiting C++
language features to provide maximum performance and maximum flexibility for
expert users. mlpack outperforms competing machine learning libraries by large
margins.

# Executables.
%package bin
Summary:        Command-line executables for mlpack (machine learning library)
Group:          Engineering
Requires:       %{name} = %{version}-%{release}

%description bin
mlpack is a C++ machine learning library with emphasis on scalability, speed,
and ease-of-use. Its aim is to make machine learning possible for novice users
by means of a simple, consistent API, while simultaneously exploiting C++
language features to provide maximum performance and maximum flexibility for
expert users. mlpack outperforms competing machine learning libraries by large
margins.  This package provides the command-line executables which run mlpack
methods and related documentation.

# Development headers.
%package devel
Summary:        Development headers for mlpack (C++ machine learning library)
Group:          System/Libraries
Requires:       %{name} = %{version}-%{release}
Requires:       boost-devel-headers boost-python-headers, boost-program-options, boost-math
Requires:	pkg-config

%description devel
mlpack is a C++ machine learning library with emphasis on scalability, speed,
and ease-of-use. Its aim is to make machine learning possible for novice users
by means of a simple, consistent API, while simultaneously exploiting C++
language features to provide maximum performance and maximum flexibility for
expert users. mlpack outperforms competing machine learning libraries by large
margins.  This package provides the headers to compile applications against
mlpack.



%package doc
Summary:        Doxygen documentation for mlpack (C++ machine learning library)
Group:          Documentation
BuildArch: noarch

%description doc
mlpack is a C++ machine learning library with emphasis on scalability, speed,
and ease-of-use.  Its aim is to make machine learning possible for novice users
by means of a simple, consistent API, while simultaneously exploiting C++
language features to provide maximum performance and maximum flexibility for
expert users.  mlpack outperforms competing machine learning libraries by large
margins.  This package provides the Doxygen-generated documentation for mlpack.

# For the F20 unversioned documentation change.  This evaluates to
# %{_docdir}/%{name} if on F20 and %{_docdir}/%{name}-%{version} otherwise.
%global our_docdir %{?_pkgdocdir}%{!?_pkgdocdir:%{_docdir}/%{name}-%{version}}

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1

%build
%if 0%{?rhel}
# On RHEL6, the Boost CMake scripts fail for some reason.  I don't have the
# time (or patience) to investigate, but if we force CMake to find Boost "the
# hard way" by specifying Boost_NO_BOOST_CMAKE=1, it works.
%{cmake28} -D Boost_NO_BOOST_CMAKE=1 -D LIBDIR=%{_libdir} -D DEBUG=OFF -D PROFILE=OFF .
%else
%{fedora_cmake} -D LIBDIR=%{_libdir} -D DEBUG=OFF -D PROFILE=OFF .
%endif

make
# Build documentation ('doc' is not in the list of default targets).
make doc


%install
make install DESTDIR=$RPM_BUILD_ROOT

# Put the license file and documentation in place.
if [ "%{our_docdir}" != "%{_docdir}/mlpack" ]; then
  mv $RPM_BUILD_ROOT/%{_docdir}/mlpack $RPM_BUILD_ROOT/%{our_docdir}
fi
mkdir -p $RPM_BUILD_ROOT/%{our_docdir}
cp LICENSE.txt $RPM_BUILD_ROOT/%{our_docdir}

# kill rpath
for i in `find %buildroot{%_bindir,%_libdir,/usr/libexec,/usr/lib,/usr/sbin} -type f -perm -111`; do
	chrpath -d $i ||:
done

%files
%{_libdir}/libmlpack.so.2
%{_libdir}/libmlpack.so.2.2
%{our_docdir}/LICENSE.txt

%files bin
%{_bindir}/mlpack_adaboost
%{_bindir}/mlpack_allknn
%{_bindir}/mlpack_allkfn
%{_bindir}/mlpack_allkrann
%{_bindir}/mlpack_approx_kfn
%{_bindir}/mlpack_cf
%{_bindir}/mlpack_dbscan
%{_bindir}/mlpack_decision_stump
%{_bindir}/mlpack_decision_tree
%{_bindir}/mlpack_det
%{_bindir}/mlpack_emst
%{_bindir}/mlpack_fastmks
%{_bindir}/mlpack_gmm_generate
%{_bindir}/mlpack_gmm_probability
%{_bindir}/mlpack_gmm_train
%{_bindir}/mlpack_hmm_generate
%{_bindir}/mlpack_hmm_loglik
%{_bindir}/mlpack_hmm_train
%{_bindir}/mlpack_hmm_viterbi
%{_bindir}/mlpack_hoeffding_tree
%{_bindir}/mlpack_kernel_pca
%{_bindir}/mlpack_kfn
%{_bindir}/mlpack_kmeans
%{_bindir}/mlpack_knn
%{_bindir}/mlpack_krann
%{_bindir}/mlpack_lars
%{_bindir}/mlpack_linear_regression
%{_bindir}/mlpack_local_coordinate_coding
%{_bindir}/mlpack_logistic_regression
%{_bindir}/mlpack_lsh
%{_bindir}/mlpack_mean_shift
%{_bindir}/mlpack_nbc
%{_bindir}/mlpack_nca
%{_bindir}/mlpack_nmf
%{_bindir}/mlpack_pca
%{_bindir}/mlpack_perceptron
%{_bindir}/mlpack_preprocess_binarize
%{_bindir}/mlpack_preprocess_describe
%{_bindir}/mlpack_preprocess_imputer
%{_bindir}/mlpack_preprocess_split
%{_bindir}/mlpack_radical
%{_bindir}/mlpack_range_search
%{_bindir}/mlpack_softmax_regression
%{_bindir}/mlpack_sparse_coding
%{_mandir}/man1/mlpack_adaboost.1*
%{_mandir}/man1/mlpack_allknn.1*
%{_mandir}/man1/mlpack_allkfn.1*
%{_mandir}/man1/mlpack_allkrann.1*
%{_mandir}/man1/mlpack_approx_kfn.1*
%{_mandir}/man1/mlpack_cf.1*
%{_mandir}/man1/mlpack_dbscan.1*
%{_mandir}/man1/mlpack_decision_stump.1*
%{_mandir}/man1/mlpack_decision_tree.1*
%{_mandir}/man1/mlpack_det.1*
%{_mandir}/man1/mlpack_emst.1*
%{_mandir}/man1/mlpack_fastmks.1*
%{_mandir}/man1/mlpack_gmm_generate.1*
%{_mandir}/man1/mlpack_gmm_probability.1*
%{_mandir}/man1/mlpack_gmm_train.1*
%{_mandir}/man1/mlpack_hmm_generate.1*
%{_mandir}/man1/mlpack_hmm_loglik.1*
%{_mandir}/man1/mlpack_hmm_train.1*
%{_mandir}/man1/mlpack_hmm_viterbi.1*
%{_mandir}/man1/mlpack_hoeffding_tree.1*
%{_mandir}/man1/mlpack_kernel_pca.1*
%{_mandir}/man1/mlpack_kfn.1*
%{_mandir}/man1/mlpack_kmeans.1*
%{_mandir}/man1/mlpack_knn.1*
%{_mandir}/man1/mlpack_krann.1*
%{_mandir}/man1/mlpack_lars.1*
%{_mandir}/man1/mlpack_linear_regression.1*
%{_mandir}/man1/mlpack_local_coordinate_coding.1*
%{_mandir}/man1/mlpack_logistic_regression.1*
%{_mandir}/man1/mlpack_lsh.1*
%{_mandir}/man1/mlpack_mean_shift.1*
%{_mandir}/man1/mlpack_nbc.1*
%{_mandir}/man1/mlpack_nca.1*
%{_mandir}/man1/mlpack_nmf.1*
%{_mandir}/man1/mlpack_pca.1*
%{_mandir}/man1/mlpack_perceptron.1*
%{_mandir}/man1/mlpack_preprocess_binarize.1*
%{_mandir}/man1/mlpack_preprocess_describe.1*
%{_mandir}/man1/mlpack_preprocess_imputer.1*
%{_mandir}/man1/mlpack_preprocess_split.1*
%{_mandir}/man1/mlpack_radical.1*
%{_mandir}/man1/mlpack_range_search.1*
%{_mandir}/man1/mlpack_softmax_regression.1*
%{_mandir}/man1/mlpack_sparse_coding.1*

%files devel
%{_libdir}/libmlpack.so
%{_includedir}/mlpack/
%{_libdir}/pkgconfig/mlpack.pc

%files doc
%{our_docdir}

%changelog
* Mon Oct 08 2018 Cronbuild Service <cronbuild@altlinux.org> 2.2.5-alt3_1
- rebuild to get rid of unmets

* Tue Jun 12 2018 Cronbuild Service <cronbuild@altlinux.org> 2.2.5-alt2_1
- rebuild to get rid of unmets

* Wed Nov 22 2017 Igor Vlasenko <viy@altlinux.ru> 2.2.5-alt1_1
- new version

* Tue May 31 2016 Igor Vlasenko <viy@altlinux.ru> 1.0.11-alt1_11
- rebuild

* Tue Jun 24 2014 Cronbuild Service <cronbuild@altlinux.org> 1.0.6-alt2_2
- rebuild to get rid of unmets

* Mon Aug 05 2013 Igor Vlasenko <viy@altlinux.ru> 1.0.6-alt1_2
- update to new release by fcimport

* Fri Apr 26 2013 Igor Vlasenko <viy@altlinux.ru> 1.0.4-alt1_3
- initial fc import

